__all__ = ["decimals"]

from . import decimals

def none_value() -> str:
    return "NONE" # NB: Has to be string and upppercase.
